import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:motor_flutter/motor_flutter.dart';

/// {@category Widgets}
/// This page is used to help guide users through the login process.
class LoginPage<T extends LoginController> extends GetView<T> {
  const LoginPage({
    Key? key,
    this.domain,
    required this.onSuccess,
  }) : super(key: key);

  final String? domain;
  final HandleLoginCallback onSuccess;

  static const domainFieldKey = Key('sonr-login-page-input-doamin');
  static const passwordFieldKey = Key('sonr-login-page-input-pawssword');
  static const continueButtonKey = Key('sonr-login-page-button-continue');

  @override
  Widget build(BuildContext context) {
    final TextEditingController domainController = TextEditingController();
    final TextEditingController passwordController = TextEditingController();

    SonrPasswordInput passwordInput = SonrPasswordInput(
      key: LoginPage.passwordFieldKey,
      controller: passwordController,
    );

    List<Widget> inputs = domain != null
        ? [passwordInput]
        : [
            SonrTextInput(
              key: LoginPage.domainFieldKey,
              label: "SonrID or .snr Domain",
              controller: domainController,
              hintText: ".Snr",
              prefixIcon: Icon(Icons.person),
            ),
            SizedBox(height: 16),
            passwordInput
          ];

    return Scaffold(
      body: controller.obx(
        (state) {
          if (state is WhoIs) {
            onSuccess(state);
          }
          return Container(
            child: Text("Login successful."),
          );
        },
        onEmpty: Container(
          padding: const EdgeInsets.all(24.0),
          child: Column(
            children: [
              const Text(
                'Hello There',
                style: NebulaTextStyles.h1,
              ),
              SizedBox(height: 16),
              if (domain == null)
                const Text(
                  "We don't recognize this device",
                  style: NebulaTextStyles.subtitle2,
                ),
              SizedBox(height: 16),
              ...inputs,
              SizedBox(height: 16),
              SonrButton(
                  key: LoginPage.continueButtonKey,
                  onPressed: () async {
                    await controller.login(
                      password: passwordController.text,
                      address: domainController.text,
                    );
                  },
                  withLogo: false,
                  label: "Continue")
            ],
          ),
        ),
        onError: (error) {
          return Center(
            child: Container(
              child: Text(error ?? 'Unknow error'),
            ),
          );
        },
      ),
    );
  }
}
