import 'package:flutter/material.dart';
import 'package:motor_flutter/motor_flutter.dart';

class SonrTextInput extends StatelessWidget {
  final String? label;
  final String? hintText;
  final TextEditingController? controller;
  final bool? obscureText;
  final VoidCallback? suffixOnPress;
  final Icon? suffixIcon;
  final VoidCallback? prefixOnPress;
  final Icon? prefixIcon;

  const SonrTextInput({
    super.key, 
    this.label,
    this.hintText,
    this.controller, 
    this.obscureText,
    this.suffixOnPress,
    this.suffixIcon,
    this.prefixOnPress,
    this.prefixIcon,
  });

  @override
  Widget build(BuildContext context) {
    return Align(
      alignment: Alignment.centerLeft,
      child: Container(
          alignment: Alignment.centerLeft,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                label ?? '',
                style: NebulaTextStyles.subtitle3,
              ),
              SizedBox(height: 6),
              TextField(
                obscureText: obscureText ?? false,
                controller: controller,
                decoration: InputDecoration(
                  hintText: hintText,
                  enabledBorder: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(6.0),
                    borderSide: BorderSide(
                      width: 2, color: NebulaColors.brandPrimary
                    ),
                  ),
                  border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(6.0),
                    borderSide: BorderSide(
                      width: 1, color: NebulaColors.brandPrimary
                    ),
                  ),
                  suffixIcon: suffixIcon != null ? IconButton(
                    onPressed: suffixOnPress,
                    icon: suffixIcon!,
                  ) : null,
                  prefixIcon: prefixIcon != null ? IconButton(
                    onPressed: prefixOnPress,
                    icon: prefixIcon!,
                  ) : null,
                ),
              ),
            ],
          )
      ),
    );
  }
}
