import 'package:get/get.dart';
import 'package:flutter/material.dart';
import 'package:motor_flutter/motor_flutter.dart';
import 'package:storybook/mocks/controllers/mock_login_controller.dart';
import 'package:storybook/mocks/controllers/mock_wallet_controller.dart';
import 'package:storybook_flutter/storybook_flutter.dart';

void main() {
  Get.lazyPut(() => FakeLoginController());
  Get.lazyPut(() => FakeWalletController());
  Get.lazyPut(() => LoginController());
  runApp(const StorybookApp());
}

class ButtonComponentWrapper extends StatelessWidget {
  const ButtonComponentWrapper({super.key, required this.children});
  final List<Widget> children;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      title: '',
      home: Scaffold(
        appBar: AppBar(),
        body: Center(
          child: Container(
            padding: const EdgeInsets.all(28.0),
            child: Column(
              children: children,
            ),
          ),
        ),
      ),
    );
  }
}

class StorybookApp extends StatelessWidget {
  const StorybookApp({super.key});

  @override
  Widget build(BuildContext context) => Storybook(
        stories: [
          Story(
            name: 'Buttons/Create Account',
            description: 'Sonr Create Account Button',
            builder: (context) => const ButtonComponentWrapper(
              children: [
                ContinueOnSonrButton(),
              ],
            ),
          ),
          Story(
            name: 'Buttons/Login',
            description: 'Sonr Login Button',
            builder: (context) => const ButtonComponentWrapper(
              children: [
                LoginButton(),
              ],
            ),
          ),
          Story(
            name: 'Pages/Login',
            description: 'Sonr Login Page',
            builder: (context) => Scaffold(
              appBar: AppBar(),
              body: Center(
                child: Container(
                  child: LoginPage<FakeLoginController>(
                    onSuccess: (_) {},
                  ),
                ),
              ),
            ),
          ),
          Story(
            name: 'Pages/Create Account',
            description: 'Sonr Create Account Page',
            builder: (context) => Scaffold(
              appBar: AppBar(),
              body: Center(
                child: Container(
                  child: CreatePasswordPage<FakeWalletController>(
                    onSuccess: (_) {},
                  ),
                ),
              ),
            ),
          ),
        ],
      );
}
