import 'package:fancy_password_field/fancy_password_field.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:get/get.dart';
import 'package:motor_flutter/motor_flutter.dart';
import 'package:motor_flutter/src/widgets/widgets.dart';

import '../../../../mocks/controllers/mock_wallet_controller.dart';

void main() {
  Widget mockWidgetsTree(Widget child) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(),
        body: Center(
          child: Container(
            child: child,
          ),
        ),
      ),
    );
  }

  setUp(() {
    Get.lazyPut(() => FakeWalletController());
  });

  testWidgets('create password page should render', (tester) async {
    await tester.pumpWidget(
      mockWidgetsTree(
        CreatePasswordPage<FakeWalletController>(
          onSuccess: (_) {},
        ),
      ),
    );
    final sonrButtonWidgets = find.byType(FancyPasswordField);
    expect(sonrButtonWidgets, findsNWidgets(1));

    // golden test
    await expectLater(
      find.byType(MaterialApp),
      matchesGoldenFile('create_account_page.png'),
    );
  });

  testWidgets('create password page should call onSuccess submit',
      (tester) async {
    await tester.pumpWidget(
      mockWidgetsTree(
        CreatePasswordPage<FakeWalletController>(
          onSuccess: (_) {},
        ),
      ),
    );

    await tester.enterText(find.byType(FancyPasswordField), 'Testing@1234');
    await tester.pump();

    // golden test
    await expectLater(
      find.byType(MaterialApp),
      matchesGoldenFile('create_account_page_inputs_filled.png'),
    );
  });

  testWidgets('create password page should call onSuccess submit',
      (tester) async {
    bool called = false;

    dynamic onSuccess(AuthInfo _) {
      called = true;
    }

    await tester.pumpWidget(
      mockWidgetsTree(
        CreatePasswordPage<FakeWalletController>(
          onSuccess: onSuccess,
        ),
      ),
    );

    expect(called, false);
    final input = find.byType(FancyPasswordField);
    await tester.enterText(input, 'Testing@1234');
    await tester.testTextInput.receiveAction(TextInputAction.done);
    await tester.pump();
    final createCredentialsButton =
        find.byKey(CreatePasswordPage.createCredentialsButtonKey);
    await tester.tap(createCredentialsButton);
    await tester.pump();
    expect(called, true);

    // golden test
    await expectLater(
      find.byType(MaterialApp),
      matchesGoldenFile('create_account_page_success.png'),
    );
  });
}
