import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/annotations.dart';
import 'package:mockito/mockito.dart';
import 'package:motor_flutter/src/widgets/widgets.dart';
import 'package:network_image_mock/network_image_mock.dart';

import 'continue_button_test.mocks.dart';

Widget _mockButtonWidgetsTree(Widget child) {
  return MaterialApp(
    home: Scaffold(
      body: Center(
        child: SizedBox(
          height: 40,
          child: child,
        ),
      ),
    ),
  );
}

@GenerateMocks([HttpClient])
void main() {
  final MockHttpClient client = MockHttpClient();

  testWidgets(
    'ContinueOnSonrButton should render whitout errors',
    (tester) async {
      await HttpOverrides.runZoned(
        () async {
          await tester
              .pumpWidget(_mockButtonWidgetsTree(ContinueOnSonrButton()));
          final labelWidget = find.text('Continue on Sonr');
          expect(labelWidget, findsOneWidget);
        },
        createHttpClient: (_) {
          when(client.getUrl(any))
              .thenAnswer((_) => successfulMockResource(kTransparentImage));

          return client;
        },
      );
    },
  );

  testWidgets('ContinueOnSonrButton golden test', (tester) async {
    await HttpOverrides.runZoned(
      () async {
        await tester.pumpWidget(_mockButtonWidgetsTree(ContinueOnSonrButton()));

        await expectLater(
          find.byType(ContinueOnSonrButton),
          matchesGoldenFile('continue_on_button.png'),
        );
      },
      createHttpClient: (_) {
        when(client.getUrl(any))
            .thenAnswer((_) => successfulMockResource(kTransparentImage));

        return client;
      },
    );
  });
}

// Http client override to mock svg on network requests
@GenerateMocks([HttpClientRequest, HttpClientResponse])
Future<HttpClientRequest> successfulMockResource(
    List<int> mockedContent) async {
  final MockHttpClientRequest request = MockHttpClientRequest();
  final MockHttpClientResponse response = MockHttpClientResponse();

  when(request.close())
      .thenAnswer((_) => Future<HttpClientResponse>.value(response));
  when(response.statusCode).thenReturn(HttpStatus.ok);
  when(response.compressionState)
      .thenReturn(HttpClientResponseCompressionState.notCompressed);
  when(response.contentLength).thenReturn(mockedContent.length);
  when(
    response.listen(
      any,
      onDone: anyNamed('onDone'),
      onError: anyNamed('onError'),
      cancelOnError: anyNamed('cancelOnError'),
    ),
  ).thenAnswer((Invocation invocation) {
    final void Function(List<int>) onData =
        invocation.positionalArguments.first as void Function(List<int>);

    return Stream<List<int>>.fromIterable(
        <List<int>>[Uint8List.fromList(mockedContent)]).listen(onData);
  });

  return request;
}

final Uint8List kTransparentImage = Uint8List.fromList(<int>[]);
